==============================================================
 Google Cloud Pub/Sub Transport - ``kombu.transport.gcpubsub``
==============================================================

.. currentmodule:: kombu.transport.gcpubsub

.. automodule:: kombu.transport.gcpubsub

    .. contents::
        :local:

    Transport
    ---------

    .. autoclass:: Transport
        :members:
        :undoc-members:

    Channel
    -------

    .. autoclass:: Channel
        :members:
        :undoc-members:
